@@ -1,4 +1,4 @@
-import seq_util
+from fosvis import seq_util
 import links
 import protein_domains
 import orf
